@@ -1,23 +1,25 @@
 import os
 
 os.environ["PYGAME_HIDE_SUPPORT_PROMPT"] = "hide"
-from pixeljump.levels.act1 import ActOne
-from pixeljump.levels.act2 import ActTwo
-from pixeljump.menu import show_menu
-from pixeljump.settings import load_settings
 
 import pygame
 
+pygame.init()
+
+from pixeljump.settings import load_settings
 
 settings = load_settings()
+
+from pixeljump.levels.act1 import ActOne
+from pixeljump.levels.act2 import ActTwo
+from pixeljump.menu import show_menu
+
+
 WIDTH = settings["window"]["screen_width"]
 HEIGHT = settings["window"]["screen_height"]
-BG_COLOR = settings["colors"]["bg"]
-FPS = settings["window"]["fps"]
 
 
 def main():
-    pygame.init()
     pygame.mixer.pre_init(44100, -16, 2, 512)
     pygame.display.set_mode((WIDTH, HEIGHT))
     pygame.display.set_caption("PIXELJUMP")
